A Django lib to expose likely intrusion attempts. Using some of the AppSensor
detection points from OWASP:

https://www.owasp.org/index.php/AppSensor_DetectionPoints

Please docs on:

https://django-paranoia.readthedocs.org/en/latest/
